==> citrus-spring-4.0.2-sources.jar: org/citrusframework/model/testcase/core/SequentialModel.java <==
//
// Diese Datei wurde mit der Eclipse Implementation of JAXB, v4.0.3 generiert 
// Siehe https://eclipse-ee4j.github.io/jaxb-ri 
// Änderungen an dieser Datei gehen bei einer Neukompilierung des Quellschemas verloren. 
//


package org.citrusframework.model.testcase.core;

import java.util.ArrayList;
import java.util.List;
import jakarta.xml.bind.JAXBElement;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAnyElement;
import jakarta.xml.bind.annotation.XmlElementRef;
import jakarta.xml.bind.annotation.XmlElementRefs;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java-Klasse für SequentialActionType complex type.
 * 
 * <p>Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.
 * 
 * <pre>{@code
 * <complexType name="SequentialActionType">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://www.citrusframework.org/schema/testcase}description" minOccurs="0"/>
 *         <group ref="{http://www.citrusframework.org/schema/testcase}actionGroup" maxOccurs="unbounded"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SequentialActionType", propOrder = {
    "description",
    "actionsAndSendsAndReceives"
})
@XmlRootElement(name = "sequential")
public class SequentialModel {

    protected String description;
    @XmlElementRefs({
        @XmlElementRef(name = "action", namespace = "http://www.citrusframework.org/schema/testcase", type = ActionModel.class, required = false),
        @XmlElementRef(name = "send", namespace = "http://www.citrusframework.org/schema/testcase", type = SendModel.class, required = false),
        @XmlElementRef(name = "receive", namespace = "http://www.citrusframework.org/schema/testcase", type = ReceiveModel.class, required = false),
        @XmlElementRef(name = "sql", namespace = "http://www.citrusframework.org/schema/testcase", type = SqlModel.class, required = false),
        @XmlElementRef(name = "plsql", namespace = "http://www.citrusframework.org/schema/testcase", type = PlsqlModel.class, required = false),
        @XmlElementRef(name = "java", namespace = "http://www.citrusframework.org/schema/testcase", type = JavaModel.class, required = false),
        @XmlElementRef(name = "sleep", namespace = "http://www.citrusframework.org/schema/testcase", type = JAXBElement.class, required = false),
        @XmlElementRef(name = "delay", namespace = "http://www.citrusframework.org/schema/testcase", type = DelayModel.class, required = false),
        @XmlElementRef(name = "trace-variables", namespace = "http://www.citrusframework.org/schema/testcase", type = TraceVariablesModel.class, required = false),
        @XmlElementRef(name = "create-variables", namespace = "http://www.citrusframework.org/schema/testcase", type = CreateVariablesModel.class, required = false),
        @XmlElementRef(name = "trace-time", namespace = "http://www.citrusframework.org/schema/testcase", type = TraceTimeModel.class, required = false),
        @XmlElementRef(name = "echo", namespace = "http://www.citrusframework.org/schema/testcase", type = JAXBElement.class, required = false),
        @XmlElementRef(name = "print", namespace = "http://www.citrusframework.org/schema/testcase", type = PrintModel.class, required = false),
        @XmlElementRef(name = "expect-timeout", namespace = "http://www.citrusframework.org/schema/testcase", type = ExpectTimeoutModel.class, required = false),
        @XmlElementRef(name = "purge-endpoint", namespace = "http://www.citrusframework.org/schema/testcase", type = PurgeEndpointModel.class, required = false),
        @XmlElementRef(name = "purge-jms-queues", namespace = "http://www.citrusframework.org/schema/testcase", type = PurgeJmsQueuesModel.class, required = false),
        @XmlElementRef(name = "purge-channel", namespace = "http://www.citrusframework.org/schema/testcase", type = PurgeChannelModel.class, required = false),
        @XmlElementRef(name = "call-template", namespace = "http://www.citrusframework.org/schema/testcase", type = CallTemplateModel.class, required = false),
        @XmlElementRef(name = "input", namespace = "http://www.citrusframework.org/schema/testcase", type = InputModel.class, required = false),
        @XmlElementRef(name = "iterate", namespace = "http://www.citrusframework.org/schema/testcase", type = IterateModel.class, required = false),
        @XmlElementRef(name = "load", namespace = "http://www.citrusframework.org/schema/testcase", type = LoadModel.class, required = false),
        @XmlElementRef(name = "repeat-until-true", namespace = "http://www.citrusframework.org/schema/testcase", type = RepeatUntilTrueModel.class, required = false),
        @XmlElementRef(name = "repeat-onerror-until-true", namespace = "http://www.citrusframework.org/schema/testcase", type = RepeatOnerrorUntilTrueModel.class, required = false),
        @XmlElementRef(name = "conditional", namespace = "http://www.citrusframework.org/schema/testcase", type = ConditionalModel.class, required = false),
        @XmlElementRef(name = "sequential", namespace = "http://www.citrusframework.org/schema/testcase", type = SequentialModel.class, required = false),
        @XmlElementRef(name = "async", namespace = "http://www.citrusframework.org/schema/testcase", type = AsyncModel.class, required = false),
        @XmlElementRef(name = "timer", namespace = "http://www.citrusframework.org/schema/testcase", type = TimerModel.class, required = false),
        @XmlElementRef(name = "stop-timer", namespace = "http://www.citrusframework.org/schema/testcase", type = StopTimerModel.class, required = false),
        @XmlElementRef(name = "fail", namespace = "http://www.citrusframework.org/schema/testcase", type = FailModel.class, required = false),
        @XmlElementRef(name = "parallel", namespace = "http://www.citrusframework.org/schema/testcase", type = ParallelModel.class, required = false),
        @XmlElementRef(name = "catch", namespace = "http://www.citrusframework.org/schema/testcase", type = CatchModel.class, required = false),
        @XmlElementRef(name = "assert", namespace = "http://www.citrusframework.org/schema/testcase", type = AssertModel.class, required = false),
        @XmlElementRef(name = "groovy", namespace = "http://www.citrusframework.org/schema/testcase", type = GroovyModel.class, required = false),
        @XmlElementRef(name = "transform", namespace = "http://www.citrusframework.org/schema/testcase", type = TransformModel.class, required = false),
        @XmlElementRef(name = "ant", namespace = "http://www.citrusframework.org/schema/testcase", type = AntModel.class, required = false),
        @XmlElementRef(name = "start", namespace = "http://www.citrusframework.org/schema/testcase", type = StartModel.class, required = false),
        @XmlElementRef(name = "stop", namespace = "http://www.citrusframework.org/schema/testcase", type = StopModel.class, required = false),
        @XmlElementRef(name = "wait", namespace = "http://www.citrusframework.org/schema/testcase", type = WaitModel.class, required = false)
    })
    @XmlAnyElement(lax = true)
    protected List<Object> actionsAndSendsAndReceives;

    /**
     * Ruft den Wert der description-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDescription() {
        return description;
    }

    /**
     * Legt den Wert der description-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDescription(String value) {
        this.description = value;
    }

    /**
     * Gets the value of the actionsAndSendsAndReceives property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the Jakarta XML Binding object.
     * This is why there is not a {@code set} method for the actionsAndSendsAndReceives property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getActionsAndSendsAndReceives().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link JAXBElement }{@code <}{@link EchoActionType }{@code >}
     * {@link JAXBElement }{@code <}{@link SleepActionType }{@code >}
     * {@link Object }
     * {@link ActionModel }
     * {@link AntModel }
     * {@link AssertModel }
     * {@link AsyncModel }
     * {@link CallTemplateModel }
     * {@link CatchModel }
     * {@link ConditionalModel }
     * {@link CreateVariablesModel }
     * {@link DelayModel }
     * {@link ExpectTimeoutModel }
     * {@link FailModel }
     * {@link GroovyModel }
     * {@link InputModel }
     * {@link IterateModel }
     * {@link JavaModel }
     * {@link LoadModel }
     * {@link ParallelModel }
     * {@link PlsqlModel }
     * {@link PrintModel }
     * {@link PurgeChannelModel }
     * {@link PurgeEndpointModel }
     * {@link PurgeJmsQueuesModel }
     * {@link ReceiveModel }
     * {@link RepeatOnerrorUntilTrueModel }
     * {@link RepeatUntilTrueModel }
     * {@link SendModel }
     * {@link SequentialModel }
     * {@link SqlModel }
     * {@link StartModel }
     * {@link StopModel }
     * {@link StopTimerModel }
     * {@link TimerModel }
     * {@link TraceTimeModel }
     * {@link TraceVariablesModel }
     * {@link TransformModel }
     * {@link WaitModel }
     * 
     * 
     * @return
     *     The value of the actionsAndSendsAndReceives property.
     */
    public List<Object> getActionsAndSendsAndReceives() {
        if (actionsAndSendsAndReceives == null) {
            actionsAndSendsAndReceives = new ArrayList<>();
        }
        return this.actionsAndSendsAndReceives;
    }

}

==> citrus-spring-4.1.0-sources.jar: org/citrusframework/model/testcase/core/SequentialModel.java <==
//
// Diese Datei wurde mit der Eclipse Implementation of JAXB, v4.0.4 generiert 
// Siehe https://eclipse-ee4j.github.io/jaxb-ri 
// Änderungen an dieser Datei gehen bei einer Neukompilierung des Quellschemas verloren. 
//


package org.citrusframework.model.testcase.core;

import java.util.ArrayList;
import java.util.List;
import jakarta.xml.bind.JAXBElement;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAnyElement;
import jakarta.xml.bind.annotation.XmlElementRef;
import jakarta.xml.bind.annotation.XmlElementRefs;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java-Klasse für SequentialActionType complex type.</p>
 * 
 * <p>Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.</p>
 * 
 * <pre>{@code
 * <complexType name="SequentialActionType">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://www.citrusframework.org/schema/testcase}description" minOccurs="0"/>
 *         <group ref="{http://www.citrusframework.org/schema/testcase}actionGroup" maxOccurs="unbounded"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SequentialActionType", propOrder = {
    "description",
    "actionsAndSendsAndReceives"
})
@XmlRootElement(name = "sequential")
public class SequentialModel {

    protected String description;
    @XmlElementRefs({
        @XmlElementRef(name = "action", namespace = "http://www.citrusframework.org/schema/testcase", type = ActionModel.class, required = false),
        @XmlElementRef(name = "send", namespace = "http://www.citrusframework.org/schema/testcase", type = SendModel.class, required = false),
        @XmlElementRef(name = "receive", namespace = "http://www.citrusframework.org/schema/testcase", type = ReceiveModel.class, required = false),
        @XmlElementRef(name = "sql", namespace = "http://www.citrusframework.org/schema/testcase", type = SqlModel.class, required = false),
        @XmlElementRef(name = "plsql", namespace = "http://www.citrusframework.org/schema/testcase", type = PlsqlModel.class, required = false),
        @XmlElementRef(name = "java", namespace = "http://www.citrusframework.org/schema/testcase", type = JavaModel.class, required = false),
        @XmlElementRef(name = "sleep", namespace = "http://www.citrusframework.org/schema/testcase", type = JAXBElement.class, required = false),
        @XmlElementRef(name = "delay", namespace = "http://www.citrusframework.org/schema/testcase", type = DelayModel.class, required = false),
        @XmlElementRef(name = "trace-variables", namespace = "http://www.citrusframework.org/schema/testcase", type = TraceVariablesModel.class, required = false),
        @XmlElementRef(name = "create-variables", namespace = "http://www.citrusframework.org/schema/testcase", type = CreateVariablesModel.class, required = false),
        @XmlElementRef(name = "trace-time", namespace = "http://www.citrusframework.org/schema/testcase", type = TraceTimeModel.class, required = false),
        @XmlElementRef(name = "echo", namespace = "http://www.citrusframework.org/schema/testcase", type = JAXBElement.class, required = false),
        @XmlElementRef(name = "print", namespace = "http://www.citrusframework.org/schema/testcase", type = PrintModel.class, required = false),
        @XmlElementRef(name = "expect-timeout", namespace = "http://www.citrusframework.org/schema/testcase", type = ExpectTimeoutModel.class, required = false),
        @XmlElementRef(name = "purge-endpoint", namespace = "http://www.citrusframework.org/schema/testcase", type = PurgeEndpointModel.class, required = false),
        @XmlElementRef(name = "purge-jms-queues", namespace = "http://www.citrusframework.org/schema/testcase", type = PurgeJmsQueuesModel.class, required = false),
        @XmlElementRef(name = "purge-channel", namespace = "http://www.citrusframework.org/schema/testcase", type = PurgeChannelModel.class, required = false),
        @XmlElementRef(name = "call-template", namespace = "http://www.citrusframework.org/schema/testcase", type = CallTemplateModel.class, required = false),
        @XmlElementRef(name = "input", namespace = "http://www.citrusframework.org/schema/testcase", type = InputModel.class, required = false),
        @XmlElementRef(name = "iterate", namespace = "http://www.citrusframework.org/schema/testcase", type = IterateModel.class, required = false),
        @XmlElementRef(name = "load", namespace = "http://www.citrusframework.org/schema/testcase", type = LoadModel.class, required = false),
        @XmlElementRef(name = "repeat-until-true", namespace = "http://www.citrusframework.org/schema/testcase", type = RepeatUntilTrueModel.class, required = false),
        @XmlElementRef(name = "repeat-onerror-until-true", namespace = "http://www.citrusframework.org/schema/testcase", type = RepeatOnerrorUntilTrueModel.class, required = false),
        @XmlElementRef(name = "conditional", namespace = "http://www.citrusframework.org/schema/testcase", type = ConditionalModel.class, required = false),
        @XmlElementRef(name = "sequential", namespace = "http://www.citrusframework.org/schema/testcase", type = SequentialModel.class, required = false),
        @XmlElementRef(name = "async", namespace = "http://www.citrusframework.org/schema/testcase", type = AsyncModel.class, required = false),
        @XmlElementRef(name = "timer", namespace = "http://www.citrusframework.org/schema/testcase", type = TimerModel.class, required = false),
        @XmlElementRef(name = "stop-timer", namespace = "http://www.citrusframework.org/schema/testcase", type = StopTimerModel.class, required = false),
        @XmlElementRef(name = "fail", namespace = "http://www.citrusframework.org/schema/testcase", type = FailModel.class, required = false),
        @XmlElementRef(name = "parallel", namespace = "http://www.citrusframework.org/schema/testcase", type = ParallelModel.class, required = false),
        @XmlElementRef(name = "catch", namespace = "http://www.citrusframework.org/schema/testcase", type = CatchModel.class, required = false),
        @XmlElementRef(name = "assert", namespace = "http://www.citrusframework.org/schema/testcase", type = AssertModel.class, required = false),
        @XmlElementRef(name = "groovy", namespace = "http://www.citrusframework.org/schema/testcase", type = GroovyModel.class, required = false),
        @XmlElementRef(name = "transform", namespace = "http://www.citrusframework.org/schema/testcase", type = TransformModel.class, required = false),
        @XmlElementRef(name = "ant", namespace = "http://www.citrusframework.org/schema/testcase", type = AntModel.class, required = false),
        @XmlElementRef(name = "start", namespace = "http://www.citrusframework.org/schema/testcase", type = StartModel.class, required = false),
        @XmlElementRef(name = "stop", namespace = "http://www.citrusframework.org/schema/testcase", type = StopModel.class, required = false),
        @XmlElementRef(name = "wait", namespace = "http://www.citrusframework.org/schema/testcase", type = WaitModel.class, required = false)
    })
    @XmlAnyElement(lax = true)
    protected List<Object> actionsAndSendsAndReceives;

    /**
     * Ruft den Wert der description-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDescription() {
        return description;
    }

    /**
     * Legt den Wert der description-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDescription(String value) {
        this.description = value;
    }

    /**
     * Gets the value of the actionsAndSendsAndReceives property.
     * 
     * <p>This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the actionsAndSendsAndReceives property.</p>
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * </p>
     * <pre>
     * getActionsAndSendsAndReceives().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link JAXBElement }{@code <}{@link EchoActionType }{@code >}
     * {@link JAXBElement }{@code <}{@link SleepActionType }{@code >}
     * {@link Object }
     * {@link ActionModel }
     * {@link AntModel }
     * {@link AssertModel }
     * {@link AsyncModel }
     * {@link CallTemplateModel }
     * {@link CatchModel }
     * {@link ConditionalModel }
     * {@link CreateVariablesModel }
     * {@link DelayModel }
     * {@link ExpectTimeoutModel }
     * {@link FailModel }
     * {@link GroovyModel }
     * {@link InputModel }
     * {@link IterateModel }
     * {@link JavaModel }
     * {@link LoadModel }
     * {@link ParallelModel }
     * {@link PlsqlModel }
     * {@link PrintModel }
     * {@link PurgeChannelModel }
     * {@link PurgeEndpointModel }
     * {@link PurgeJmsQueuesModel }
     * {@link ReceiveModel }
     * {@link RepeatOnerrorUntilTrueModel }
     * {@link RepeatUntilTrueModel }
     * {@link SendModel }
     * {@link SequentialModel }
     * {@link SqlModel }
     * {@link StartModel }
     * {@link StopModel }
     * {@link StopTimerModel }
     * {@link TimerModel }
     * {@link TraceTimeModel }
     * {@link TraceVariablesModel }
     * {@link TransformModel }
     * {@link WaitModel }
     * </p>
     * 
     * 
     * @return
     *     The value of the actionsAndSendsAndReceives property.
     */
    public List<Object> getActionsAndSendsAndReceives() {
        if (actionsAndSendsAndReceives == null) {
            actionsAndSendsAndReceives = new ArrayList<>();
        }
        return this.actionsAndSendsAndReceives;
    }

}
